==> cloudt-system-api-3.0.1.1-20220809.102801-6-sources.jar: com/elitescloud/cloudt/comm/service/ComCityCodeProviderService.java <==
package com.elitescloud.cloudt.comm.service;

import com.elitescloud.cloudt.comm.consumer.dto.ComCityCodeRpcDTO;
import com.elitescloud.cloudt.Application;
import com.elitescloud.cloudt.comm.consumer.param.ComCityCodeRpcDtoParam;
import com.elitescloud.cloudt.comm.vo.ComCityCodeVO;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestParam;

import javax.validation.constraints.NotNull;
import java.util.List;

/**
 * 城市编码服务
 * <p>
 * 内部流转按照 id 进行传参
 * 对外接口一律按照 code 进行传参数
 *
 * @author Chris
 * @date 2021-03-24
 */
@FeignClient(name = Application.NAME, path = ComCityCodeProviderService.URI)
@Validated
public interface ComCityCodeProviderService {
    String URI = Application.URI_PREFIX + "/cityCode";

    /**
     * 获取区域信息列表，该接口一般应用与如下场景
     * 1. 第三方通过id或者code获取一些基本信息，用于后端组装数据
     * 2. 检查数据是否存在，存在则会返回数据，不存在则不会返回数据
     * <p>
     * 如果传入的查询参数均为空，则不返回任何数据，防止获取全部数据
     * <p>
     * 注意接口返回数据没有上限控制，请合理使用，保证效能
     * 该接口在服务端配置 timeout 时间为 5s
     * 如果遇到 timeout 问题，请和开发协调沟通进行优化
     *
     * @param param dto 查询条件，每个条件使用 and 关联
     * @return dto
     */
    @PostMapping(value = "/findRpcDtoByParam")
    List<ComCityCodeRpcDTO> findRpcDtoByParam(ComCityCodeRpcDtoParam param);

    /**
     * 获取全部区域数据
     *
     * @return 数据
     */
    @GetMapping(value = "/findAllCityCodes")
    List<ComCityCodeVO> findAllCityCodes();

    /**
     * 根据 pid 获取子区域
     *
     * @param pid pid
     * @return 区域
     */
    @GetMapping(value = "/findByPid")
    List<ComCityCodeVO> findByPid(@RequestParam(name = "pid") @NotNull(message = "pid为空") Long pid);

    /**
     * 获取所有区域信息(仅限省市区)
     *
     * @return
     */
    @GetMapping(value = "/findAllCityCodesTillCounty")
    List<ComCityCodeVO> findAllCityCodesTillCounty();
}

==> cloudt-system-api-3.0.2-20220817.035839-2-sources.jar: com/elitescloud/cloudt/comm/service/ComCityCodeProviderService.java <==
package com.elitescloud.cloudt.comm.service;

import com.elitescloud.cloudt.comm.consumer.dto.ComCityCodeRpcDTO;
import com.elitescloud.cloudt.Application;
import com.elitescloud.cloudt.comm.consumer.param.ComCityCodeRpcDtoParam;
import com.elitescloud.cloudt.comm.vo.ComCityCodeVO;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

import javax.validation.constraints.NotNull;
import java.util.List;

/**
 * 城市编码服务
 * <p>
 * 内部流转按照 id 进行传参
 * 对外接口一律按照 code 进行传参数
 *
 * @author Chris
 * @date 2021-03-24
 */
@FeignClient(name = Application.NAME, path = ComCityCodeProviderService.URI)
@Validated
public interface ComCityCodeProviderService {
    String URI = Application.URI_PREFIX + "/cityCode";

    /**
     * 获取区域信息列表，该接口一般应用与如下场景
     * 1. 第三方通过id或者code获取一些基本信息，用于后端组装数据
     * 2. 检查数据是否存在，存在则会返回数据，不存在则不会返回数据
     * <p>
     * 如果传入的查询参数均为空，则不返回任何数据，防止获取全部数据
     * <p>
     * 注意接口返回数据没有上限控制，请合理使用，保证效能
     * 该接口在服务端配置 timeout 时间为 5s
     * 如果遇到 timeout 问题，请和开发协调沟通进行优化
     *
     * @param param dto 查询条件，每个条件使用 and 关联
     * @return dto
     */
    @PostMapping(value = "/findRpcDtoByParam")
    List<ComCityCodeRpcDTO> findRpcDtoByParam(@RequestBody ComCityCodeRpcDtoParam param);

    /**
     * 获取全部区域数据
     *
     * @return 数据
     */
    @GetMapping(value = "/findAllCityCodes")
    List<ComCityCodeVO> findAllCityCodes();

    /**
     * 根据 pid 获取子区域
     *
     * @param pid pid
     * @return 区域
     */
    @GetMapping(value = "/findByPid")
    List<ComCityCodeVO> findByPid(@RequestParam(name = "pid") @NotNull(message = "pid为空") Long pid);

    /**
     * 获取所有区域信息(仅限省市区)
     *
     * @return
     */
    @GetMapping(value = "/findAllCityCodesTillCounty")
    List<ComCityCodeVO> findAllCityCodesTillCounty();
}
